Pool

Struct Pool 

pub struct Pool<T> { /* private fields */ }
The pseudo-pool container. This holds the inventory of objects that can be checked in/out & automatically tracks when checked out objects are out of scope to return them to the pool. The objects can carry payloads (which must all be of the same type).

Implementations

Source

impl<T> Pool<T>

pub fn new() -> Self

Create a new, empty pool.

pub fn new_from_iterable<V: IntoIterator<Item = T>>(vec: V) -> Self

Create a new pool with initial contents from an iterable of object payloads.

pub fn add_entry(&mut self, payload: T)

Add an object, with a specific payload, to the pool.

pub fn extend_entries<V: IntoIterator<Item = T>>(&mut self, vec: V)

Add objects to the pool from an iterable of payloads.

pub fn checkout_blocking(&mut self) -> Result<ExternalPoolEntry<T>>

Get an object from the pool, if available, or block until an object is available. Returns the object. (This is the entire reason this crate exists.)

pub fn try_checkout(&mut self) -> Option<ExternalPoolEntry<T>>

Get an object from the pool, wrapped in an Option, if available, or None if there are no such objects currently.

pub fn update_leases(&mut self) -> usize

Update the available objects with recently returned objects. Returns the count of available objects.

pub fn leases(&self) -> usize

Get the number of available objects in the pool. May be inaccurate (lower than the actual number) if objects have been returned, but no checkout or update_leases have occurred.